##############################################
## PrRepression.R
## Purpose: Probability of repression in urban and rural areas
## Date: December 4, 2016 
##############################################

rm(list = ls()); gc()

##############################################
## LOADING PREPPED SCAD DATA:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

##############################################
## Pr(Repress) & Pr(Lethal | Repress) by Urban
## Bootstrapped 95% CIs
##############################################

# Number of simulations:
Nsims <- 1000

# Pr(Repress)
pr_repress <- matrix(NA, nrow = Nsims, ncol = 2)
temp_dt <- scad_dt[!is.na(urban)]
N_temp <- nrow(temp_dt)

for(i in 1:Nsims) {
    samp <- sample(1:N_temp, N_temp, replace = TRUE)
    pr_repress[i,] <- temp_dt[samp, mean(any_repress, na.rm = TRUE),
        by = urban][order(urban)][[2]]
}

tab1_dt <- rbind(
    c(mean(pr_repress[,1]), quantile(pr_repress[,1], c(.025, .975))),
    c(mean(pr_repress[,2]), quantile(pr_repress[,2], c(.025, .975)))) %>%
    data.table()
tab1_dt <- tab1_dt %>% round(2)
setnames(tab1_dt, 2:3, c("lb", "ub"))
tab1_dt[, pr := paste0(V1, " [", lb, ", ", ub, "]")]

##############################################
# Pr(Lethal | Repression)
pr_lethal <- matrix(NA, nrow = Nsims, ncol = 2)
temp_dt <- scad_dt[!is.na(urban) & any_repress == 1]
N_temp <- nrow(temp_dt)

for(i in 1:Nsims) {
    samp <- sample(1:N_temp, N_temp, replace = TRUE)
    pr_lethal[i,] <- temp_dt[samp, mean(lethal_repress, na.rm = TRUE),
        by = urban][order(urban)][[2]]
}
rm(list = c("temp_dt", "samp", "Nsims", "N_temp"))

tab2_dt <- rbind(
    c(mean(pr_lethal[,1]), quantile(pr_lethal[,1], c(.025, .975))),
    c(mean(pr_lethal[,2]), quantile(pr_lethal[,2], c(.025, .975)))) %>%
    data.table()
tab2_dt <- tab2_dt %>% round(2)
setnames(tab2_dt, 2:3, c("lb", "ub"))
tab2_dt[, pr := paste0(V1, " [", lb, ", ", ub, "]")]

tab_dt <- cbind(c("Rural", "Urban"), tab1_dt[, pr], tab2_dt[, pr]) %>%
    data.table()
setnames(tab_dt, c("Location", "Pr(Repression)", "Pr(Lethal | Repression)"))

##############################################
## TABLE 1:
############################################## 

setwd(tabs_dir)
stargazer(tab_dt,
    summary = FALSE, rownames = FALSE, digits = 2,
    title = "Two Patterns of Repression across Urban and Rural Areas",
    label = "tab:pr_repress",
    out = "PrRepress.tex")

rm(list = c("tab1_dt", "tab2_dt", "pr_repress", "pr_lethal"))

##############################################
## PR(REPRESSION) BY COUNTRY
##############################################

# Pr(Repression)
temp_dt <- scad_dt[!is.na(urban), list(
    pr_repress = mean(any_repress, na.rm = TRUE),
    Nobs = .N),
    by = list(urban, wb)][order(wb, urban)]

plot_dt <- temp_dt[, list(
    pr_repress_diff = diff(pr_repress),
    min_obs = min(Nobs)),
    by = wb]

##############################################
# Pr(Lethal | Repression)
temp_dt <- scad_dt[!is.na(urban) & any_repress == 1, list(
    pr_lethal = mean(lethal_repress, na.rm = TRUE)),
    by = list(urban, wb)][order(wb, urban)]

plot2_dt <- temp_dt[, list(pr_lethal_diff = diff(pr_lethal)), by = wb]

##############################################
# Combining for Plot:
setkey(plot_dt, wb); setkey(plot2_dt, wb)
plot_dt <- merge(plot_dt, plot2_dt)
plot_dt[, expected := as.integer(pr_repress_diff > 0 & pr_lethal_diff < 0)]

##############################################
## FIGURE 1: 
############################################## 

setwd(figs_dir)
pdf(file = "PrRepress_byCountry.pdf")
ggplot() +
    geom_rect(aes(xmin = 0, xmax = .35, ymin = -.8, ymax = 0),
        fill = "grey90") +
    geom_vline(xintercept = 0, lty = 2, color = "grey50") +
    geom_hline(yintercept = 0, lty = 2, color = "grey50") +
    geom_text(data = plot_dt[min_obs > 10 & expected == 0],
        aes(x = pr_repress_diff, y = pr_lethal_diff, label = wb),
        family = "mono") +
    geom_text(data = plot_dt[min_obs > 10 & expected == 1],
        aes(x = pr_repress_diff, y = pr_lethal_diff, label = wb),
        family = "mono", fontface = "bold") +
    scale_x_continuous("\nDifference in Pr(Repression)",
        breaks = c(-.15, 0, .3)) +
    scale_y_continuous("\nDifference in Pr(Lethal | Repression)",
        breaks = c(-.8, -.5, 0, .10)) +
    annotate("text", x = .175, y = -.85,
        label = "Pr(Repress) Higher in Cities",
        family = "serif", fontface = "bold") +
    annotate("text", x = .375, y = -.4, angle = 270,
        label = "Pr(Lethal Repression) Higher in Rural Areas",
        family = "serif", fontface = "bold") +
    coord_cartesian(xlim = c(-.2, .4)) +
    theme_bw() + opts
dev.off()

