##############################################
## Alt_MultipleSources.R
## Purpose: Alternative Explanation: Reporting Bias
## Date: December 4, 2016
##############################################

rm(list = ls()); gc()

##############################################
## LOADING SCAD:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

##############################################
## PR(Multiple Sources) by Repression and Location:
##############################################

# Cleaning number of sources variables:
scad_dt[nsource %in% c("AFP", "AP"), nsource := "0"]
scad_dt[nsource == "Both", nsource := "1"]
scad_dt[, nsource := as.integer(nsource)]

##############################################
## TABLE 6: 
############################################## 

# Urban events are more likely to be covered by multiple sources:
tab_dt <- scad_dt[!is.na(urban),
    list(pr_mult_src = mean(nsource == 1, na.rm = TRUE)),
    by = list(urban, repress)][order(urban, repress)] %>% round(2)
tab_dt <- dcast(tab_dt, urban ~ repress)
# Manually inputted to latex table.

##############################################
## REGRESSION MODELS:
##############################################

m1 <- felm(nsource ~ lethal_repress * urban | ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])

m2 <- felm(nsource ~ lethal_repress * urban |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt[any_repress == 1])

##############################################
## ADDITIONAL MODEL INFORMATION:
##############################################

m1_ct <- scad_dt[!is.na(lethal_repress) & !is.na(urban) &
    !is.na(ccode) & !is.na(eyr) & !is.na(nsource) & any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_)]

m2_ct <- scad_dt[!is.na(lethal_repress) & !is.na(urban) &
    !is.na(ccode) & !is.na(eyr) & !is.na(nsource) & !is.na(issue_type) &
    !is.na(govt_target) & !is.na(tactic) & !is.na(event_type) &
    any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)))]

ct_dt <- rbindlist(list(m1_ct, m2_ct))

##############################################
## TABLE 7:
##############################################

# Covariate Labels
covars <- c("$\\mathbb{1}$(Urban)", "$\\mathbb{1}$(Lethal)", "$\\mathbb{1}$(Urban)$\\times$$\\mathbb{1}$(Lethal)")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))
leader_FE <- c("Leader FEs", format(ct_dt[, nldr],big.mark = ",", trim = TRUE))

event_cntrls <- c("\\midrule Event Controls", "", "\\checkmark")

add_lines <- list(year_FE, cntry_FE, leader_FE, event_cntrls)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

setwd(tabs_dir)
stargazer(list(m1, m2),
    dep.var.labels = c("$\\mathbb{1}$(Multiple News Sources)"),
    covariate.labels = covars,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:alt_nsource",
    title = "Pr(Multiple Sources) by Lethal Repression and Location",
    out = "Alt_Nsource.tex")
