##############################################
## Alt_ReporterProximity.R
## Purpose: Alternative Explanation: Reporting Bias
## Date: December 4, 2016
##############################################

rm(list = ls()); gc()

##############################################
## SOURCING DISTANCE FUNCTIONS:
##############################################
 
# Sourcing C++ Functions:
invisible(sapply(c("Rcpp", "RcppArmadillo"), require, character.only = TRUE))
sourceCpp(paste0(top_dir, "/Code/DistanceFunctions.cpp"))

##############################################
## LOADING AND TRANSFORMING AP DATA:
##############################################

setwd(paste0(data_dir, "AP"))
load("AP_Stories_LatLng.Rdata")

# Getting the year of the story:
ap_geo_dt[, ld_date_parse := mdy(ld_date)]
ap_geo_dt[, ld_date_year := year(ld_date_parse)]

ap_geo_dt[, stry_date_year := gsub(".*([0-9]{4}).*", "\\1", stry_date)]

ap_geo_dt[, comb_year := ld_date_year]
ap_geo_dt[is.na(comb_year), comb_year := as.integer(stry_date_year)]

##############################################
# Number of stories by city and year:
city_yr_dt <- ap_geo_dt[!is.na(latitude),
    list(.N, latitude, longitude),
    by = list(clean_dateline, comb_year)] %>%
    unique()

city_yr_dt[, latitude := as.numeric(latitude)]
city_yr_dt[, longitude := as.numeric(longitude)]

city_yr_dt[, avg_N := mean(N), by = clean_dateline]
city_yr_dt[, med_N := NA_real_]
city_yr_dt[, med_N := median(N) %>% as.numeric(), by = clean_dateline]

city_yr_dt[, quantile(med_N, seq(0, 1, .15))]
city_yr_dt[, quantile(avg_N, seq(0, 1, .15))]

setkey(city_yr_dt, clean_dateline, comb_year)
city_yr_dt[, mv_avg := rollapply(N, width = 3, mean,
    align = "right", partial = TRUE)]


##############################################
## LOADING SCAD:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

##############################################
## MINIMUM DIST BETWEEN SCAD EVENT AND REPORTER LOCATION
##############################################

scad_dt[, c("ap_dist_hub", "ap_dist_any") := NA_real_]

for(i in 1:nrow(scad_dt)) {
    pt <- scad_dt[i, .(longitude, latitude)] %>% as.numeric()
    pt_yr <- scad_dt[i, eyr]

    # Cutoff rule for a HUB is an average of 5 articles in each of the past three years. 5 articles is between the 50th and 60th percentiles.

    # Cutoff rule for ANY filing location is just an article in the previous year.
    if(pt_yr == 1990) {
        # Using 1990 stories if year == 1990 (given no "pre" data)
        xy_mat <- city_yr_dt[mv_avg >= 5 & comb_year == pt_yr,
            .(longitude, latitude)] %>% as.matrix()

        full_xy_mat <- city_yr_dt[comb_year == pt_yr,
            .(longitude, latitude)] %>% as.matrix()

    } else {
        # Lagging if year > 1990
        xy_mat <- city_yr_dt[mv_avg >= 5 & comb_year == (pt_yr - 1),
            .(longitude, latitude)] %>% as.matrix()

        full_xy_mat <- city_yr_dt[comb_year == (pt_yr - 1),
            .(longitude, latitude)] %>% as.matrix()
    }

    # Minimum distance to reporting "hub":
    scad_dt[i, ap_dist_hub := MinDist(pt, xy_mat)]
    # Minimum distance to any filing location in previous year:
    scad_dt[i, ap_dist_any := MinDist(pt, full_xy_mat)]
}

##############################################
## RELATIONSHIP BETWEEN POP DENSITY AND DISTANCE TO REPORTERS
##############################################

m1 <- felm(lethal_repress ~ ln_popdens + ap_dist_hub |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])

m2 <- felm(lethal_repress ~ ln_popdens + ap_dist_hub |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt[any_repress == 1])

m3 <- felm(lethal_repress ~ ln_popdens + ap_dist_any |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])

m4 <- felm(lethal_repress ~ ln_popdens + ap_dist_any |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type |
    0 | ccode,
    data = scad_dt[any_repress == 1])

##############################################
## ADDITIONAL MODEL INFORMATION:
##############################################

m1_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(ap_dist_hub) & any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_)]

m2_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(ap_dist_hub) & !is.na(issue_type) &
    !is.na(govt_target) & !is.na(tactic) & !is.na(event_type) &
    any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)))]

m3_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(ap_dist_any) & any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_)]

m4_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(ap_dist_any) & !is.na(issue_type) &
    !is.na(govt_target) & !is.na(tactic) & !is.na(event_type) &
    any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)))]

ct_dt <- rbindlist(list(m1_ct, m2_ct, m3_ct, m4_ct))

##############################################
## Table 8:
##############################################

# Covariate Labels
covars <- c("Log(Pop. Density)", "Dist. AP Reporting Hub", "Dist. AP Filing Loc.")

# Model Labels:
m_labs <- c("1", "2", "3", "4")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))
leader_FE <- c("Leader FEs", format(ct_dt[, nldr],
    big.mark = ",", trim = TRUE))

event_cntrls <- c("\\midrule Event Controls", "", "\\checkmark", "", "\\checkmark")

add_lines <- list(year_FE, cntry_FE, leader_FE, event_cntrls)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

setwd(tabs_dir)
stargazer(list(m1, m2, m3, m4),
    dep.var.labels = c("$\\mathbb{1}$(Lethal Repression)"),
    covariate.labels = covars,
    column.labels = m_labs,
    model.numbers = FALSE,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:alt_reportingbias",
    title = "Pr(Lethal Repression) by Distance to Reporting Resources",
    out = "Alt_ReportingBias.tex")

##############################################
## Table 9:
##############################################

setwd(tabs_dir)
vars <- covars[2:3]
stargazer(scad_dt[any_repress == 1 & !is.na(ln_popdens),
    .(ap_dist_hub, ap_dist_any)],
    covariate.labels = vars,
    label = "tab:sumstats_alt_reportingbias",
    title = "Summary Statistics: Pr(Lethal) by Distance to Reporting Resources",
    digits = 3,
    table.placement = "ht!",
    out = "SumStats_Alt_ReportingBias.tex")
