##############################################
## Alt_IntlAid.R
## Purpose: Alternative Explanation: International Sanctioning
## Date: December 4, 2016 
##############################################

rm(list = ls()); gc()

##############################################
## LOADING PREPPED SCAD DATA:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

##############################################
## INTERNATIONAL SANCTIONING
## DV: ODA / GDP
##############################################

setwd(data_dir)
wdi_dt <- read.dta("WDI/wdi_2011_long.dta") %>% data.table()
keep <- c("Country_Name", "year", "DT_ODA_ODAT_XP_ZS", "DT_ODA_ODAT_GN_ZS")
wdi_dt <- wdi_dt[, eval(keep), with = FALSE]
setnames(wdi_dt, c("country", "eyr", "oda_pctgni", "oda_pctgovt"))

# Merging in Country Codes:
cntry_dt <- read.dta("WDI/CountryCodes.dta") %>% data.table()
setkey(cntry_dt, country)
setkey(wdi_dt, country)
wdi_dt <- merge(wdi_dt, cntry_dt[, .(country, ccode)], all.x = TRUE)
rm(cntry_dt)

# Merging to SCAD:
setkey(scad_dt, ccode, eyr)
setkey(wdi_dt, ccode, eyr)
scad_dt <- merge(scad_dt, wdi_dt, all.x = TRUE)

##############################################
# Does ODA affect use of repression in response to protests?
m1 <- felm(any_repress ~ oda_pctgni |
    ccode + eyr | 0 | ccode,
    data = scad_dt)

m2 <- felm(any_repress ~ oda_pctgovt |
    ccode + eyr | 0 | ccode,
    data = scad_dt)

##############################################
# Does ODA affect use of lethal repression in cities?
m3 <- felm(lethal_repress ~ oda_pctgni * ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])
# This is exactly the opposite of what we'd expect.

m4 <- felm(lethal_repress ~ oda_pctgovt * ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])
# Again, not much here to suggest that the use of lethal repression in low density areas is particularly pronounced in countries receiving more aid flows.

##############################################
## ADDITIONAL MODEL INFORMATION:
##############################################

m1_ct <- scad_dt[!is.na(any_repress) & !is.na(oda_pctgni) &
    !is.na(ccode) & !is.na(eyr),
    list(nyear = length(unique(eyr)), ncntry = length(unique(ccode)))]

m2_ct <- scad_dt[!is.na(any_repress) & !is.na(oda_pctgovt) &
    !is.na(ccode) & !is.na(eyr),
    list(nyear = length(unique(eyr)), ncntry = length(unique(ccode)))]

m3_ct <- scad_dt[!is.na(lethal_repress) & !is.na(oda_pctgni) &
    !is.na(ln_popdens) & !is.na(ccode) & !is.na(eyr) &
    any_repress == 1,
    list(nyear = length(unique(eyr)), ncntry = length(unique(ccode)))]

m4_ct <- scad_dt[!is.na(lethal_repress) & !is.na(oda_pctgovt) &
    !is.na(ln_popdens) & !is.na(ccode) & !is.na(eyr) &
    any_repress == 1,
    list(nyear = length(unique(eyr)), ncntry = length(unique(ccode)))]

ct_dt <- rbindlist(list(m1_ct, m2_ct, m3_ct, m4_ct))

##############################################
## REGRESSION TABLE:
##############################################

# Covariate Labels
covars <- c("ODA \\% GDP", "ODA \\% Govt. Rev.", "Log(Pop. Density)",
    "Log(Pop. Density) $\\times$ ODA \\% GDP", "Log(Pop. Density) $\\times$ ODA \\% Govt. Rev.")

m_labs <- c("1 (Full)", "2 (Full)", "3 (Repressed)", "4 (Repressed)")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))

add_lines <- list(cntry_FE, year_FE)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

##############################################
## TABLE 10: 
############################################## 

setwd(tabs_dir)
stargazer(list(m1, m2, m3, m4),
    dep.var.labels = c("$\\mathbb{1}$(Repression)", "$\\mathbb{1}$(Lethal Repression)"),
    covariate.labels = covars,
    column.labels = m_labs,
    model.numbers = FALSE,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:alt_intlaid",
    title = "International Aid and Repression",
    out = "Alt_IntlAid.tex")

##############################################
## TABLE 11:
##############################################

setwd(tabs_dir)
stargazer(scad_dt[, .(oda_pctgni, oda_pctgovt)],
    covariate.labels = covars[1:2],
    label = "tab:sumstats_alt_intlaid",
    title = "Summary Statistics: International Aid",
    digits = 3,
    table.placement = "ht!",
    out = "SumStats_Alt_IntlAid.tex")
