##############################################
## Alt_ArmedConf.R
## Purpose: Alternative Explanation: Armed Conflict
## Date: December 4, 2016 
##############################################

rm(list = ls()); gc()

##############################################
## SOURCING DISTANCE FUNCTIONS:
##############################################

# Sourcing C++ Functions:
invisible(sapply(c("Rcpp", "RcppArmadillo"), require, character.only = TRUE))
sourceCpp(paste0(top_dir, "/Code/DistanceFunctions.cpp"))

##############################################
## LOADING PREPPED SCAD DATA:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

##############################################
## CALCULATING CONFLICTS & DEATHS
## WITHIN 50KM AND 5 YEARS
##############################################

setwd(data_dir)
ucdp_shp <- readOGR(dsn = "ged30-shp", layer = "ged30")
ucdp_xy <- coordinates(ucdp_shp)
ucdp_dt <- ucdp_shp@data %>% data.table()

ucdp_dt[, date_start := ymd(date_start)]
ucdp_dt[, date_end := ymd(date_end)]

pb <- txtProgressBar(min = 0, max = nrow(scad_dt), style = 3)
for(i in 1:nrow(scad_dt)) {
    pt <- scad_dt[i, .(longitude, latitude)] %>% as.numeric()
    d_vec <- Dist(as.numeric(pt), ucdp_xy)

    # Conflicts within 50km:
    conf_rows <- which(d_vec <= 50)

    if(length(conf_rows) == 0) {
        scad_dt[i, c("conf_5yr_ct", "conf_5yr_deaths") := 0L]
    } else {
        temp_dt <- ucdp_dt[conf_rows, .(date_start, date_end, best_est)]

        # Before SCAD Event:
        temp_dt <- temp_dt[date_end <= scad_dt[i, edate]]

        # And w/in 5 years:
        temp_dt <- temp_dt[date_end >= (scad_dt[i, edate] - years(5))]

        # Number of conflicts and total deaths:
        scad_dt[i, conf_5yr_deaths := temp_dt[, sum(best_est, na.rm = TRUE)]]
        scad_dt[i, conf_5yr_ct := nrow(temp_dt)]
    }
    rm(list = c("pt", "d_vec", "conf_rows", "temp_dt"))
    setTxtProgressBar(pb, i)
}

##############################################
## REGRESSION MODELS
##############################################

m1 <- felm(lethal_repress ~ ln_popdens + conf_5yr_ct |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])

m2 <- felm(lethal_repress ~ ln_popdens + as.integer(conf_5yr_ct > 0) |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])

m3 <- felm(lethal_repress ~ ln_popdens + conf_5yr_deaths |
    ccode + eyr | 0 | ccode,
    data = scad_dt[any_repress == 1])

m4 <- felm(lethal_repress ~ ln_popdens + conf_5yr_ct |
    leader_code + ccode + eyr +
    issue_type + govt_target + tactic + event_type
    | 0 | ccode,
    data = scad_dt[any_repress == 1])

##############################################
## ADDITIONAL MODEL INFORMATION
##############################################

m1_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(conf_5yr_ct) & any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_)]

m3_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & !is.na(conf_5yr_deaths) & any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = NA_integer_)]

m4_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(groupname) & !is.na(eyr) & !is.na(conf_5yr_ct) &
    !is.na(issue_type) & !is.na(govt_target) & !is.na(tactic) & !is.na(event_type) & any_repress == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)),
    nldr = length(unique(leader_code)))]

ct_dt <- rbindlist(list(m1_ct, m1_ct, m3_ct, m4_ct))

##############################################
## TABLE 12:
##############################################

# Covariate Labels
covars <- c("Log(Pop. Density)", "$\\Sigma$ Conflicts (50km, 5yr)", "$\\mathbb{1}$(Conflict) (50km, 5yr)", "$\\Sigma$ Deaths (50km, 5yr)")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))
leader_FE <- c("Leader FEs", format(ct_dt[, nldr],
    big.mark = ",", trim = TRUE))

event_cntrls <- c("\\midrule Event Controls", "", "", "", "\\checkmark")

add_lines <- list(year_FE, cntry_FE, leader_FE, event_cntrls)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

setwd(tabs_dir)
stargazer(list(m1, m2, m3, m4),
    dep.var.labels = c("$\\mathbb{1}$(Lethal Repression)"),
    covariate.labels = covars,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:alt_armedconf",
    title = "Pr(Lethal Repression) Given History of Armed Conflict",
    out = "Alt_ArmedConf.tex")

##############################################
## TABLE 13:
##############################################

setwd(tabs_dir)
vars <- c("$\\Sigma$ Conflicts (50km, 5yr)", "$\\Sigma$ Deaths (50km, 5yr)")
stargazer(scad_dt[any_repress == 1 & !is.na(ln_popdens),
    .(conf_5yr_ct, conf_5yr_deaths)],
    covariate.labels = vars,
    label = "tab:sumstats_alt_armedconf",
    title = "Summary Statistics: Pr(Lethal) Given History of Armed Conflict",
    digits = 3,
    table.placement = "ht!",
    out = "SumStats_Alt_ArmedConf.tex")
