##############################################
## PrepSCAD.R
## Purpose: Load prepared SCAD Data
## Date: February 8, 2016
##############################################

setwd(data_dir)
scad_dt <- read_csv("SCAD/SCAD 3.1.csv") %>%
    data.table()

##############################################
# FIXING GEO-LOCATIONS FOR JO-BURG:
scad_dt[ilocal == "Johannesburg" & latitude == 28.0455,
    c("latitude", "longitude") := list(-26.2015, 28.0455)]

##############################################
# Removing the following observations:
    # Event ID < 0: Occur during an armed conflict;
    # Sublocal != 1: Not primary location of conflict;
    # Location precision == "no": Geo-coding is impercise.
scad_dt <- scad_dt[eventid > 0 & sublocal == 1 & is.na(location_precision)]

##############################################
# Parsing Dates:
scad_dt[, startdate := ymd(startdate)]
scad_dt[, enddate := ymd(enddate)]

##############################################
# Urban and Rural Indicators:
scad_dt[, urban := NA_integer_]
scad_dt[locnum %in% c(1:2, 4), urban := 1L]
scad_dt[locnum %in% c(3, 5), urban := 0L]

scad_dt[, rural := NA_integer_]
scad_dt[locnum %in% c(3, 5), rural := 1L]
scad_dt[locnum %in% c(1:2, 4), rural := 0L]

# Repression Indicators:
scad_dt[, any_repress := as.integer(repress %in% 1:2)]
scad_dt[, lethal_repress := as.integer(repress ==2)]

##############################################
# Alternative Classification of Issule Types:
scad_dt[issue1 %in% c(1, 8, 9, 10, 11), issue_type := "Political"]
scad_dt[issue1 %in% c(2, 3, 7, 12), issue_type := "Economic"]
scad_dt[issue1 %in% c(5, 6), issue_type := "Ethnic"]
scad_dt[issue1 %in% c(4, 13), issue_type := "Other"]
scad_dt[issue1 == 14, issue_type := "Unknown"]

##############################################
# Alternative Classification of Event Types:
scad_dt[etype %in% c(1, 3, 5, 6, 8, 9, 10), event_type := "Organized"]
scad_dt[etype %in% c(2, 4), event_type := "Spontaneous"]

##############################################
# Alternative classification of tactics:
scad_dt[etype %in% c(3, 4, 7, 8, 9, 10), tactic := "Violent"]
scad_dt[etype %in% c(1, 2, 5, 6), tactic := "Non-Violent"]

##############################################
# Government Target:
scad_dt[, govt_target := NA_integer_]
scad_dt[cgovtarget == 1 | rgovtarget == 1, govt_target := 1L]
scad_dt[cgovtarget == 0 & rgovtarget == 0, govt_target := 0L]

##############################################
# Merging WB codes:
code_dt <- countrycode_data %>% data.table()
setnames(code_dt, "cown", "ccode")

setkey(code_dt, ccode)
setkey(scad_dt, ccode)
scad_dt <- merge(scad_dt, code_dt[,.(ccode, wb)], all.x = TRUE)

##############################################
## MERGING LANDSCAN DATA:
##############################################

setwd(data_dir)
ls_r <- raster("LandScan/Population/lspop2011/w001001.adf")
scad_xy <- unique(scad_dt[, .(longitude, latitude)])

# Extracting to SCAD Points:
pop_dens <- extract(ls_r, scad_xy, method = "bilinear")
# Bilinear: The returned values are interpolated from the values of the four nearest raster cells.

scad_xy[, pop_dens := pop_dens]

# Checking on points with missing population density...
# These six points occur on coastlines and islands.
# ggplot() +
#     geom_point(data = scad_xy[!is.na(pop_dens)],
#         aes(x = longitude, y = latitude)) +
#     geom_point(data = scad_xy[is.na(pop_dens)],
#         aes(x = longitude, y = latitude), color = "red")

setkey(scad_xy, longitude, latitude)
setkey(scad_dt, longitude, latitude)
scad_dt <- merge(scad_dt, scad_xy, all.x = TRUE)

rm(list = c("ls_r", "scad_xy"))

# Logging population density:
scad_dt[, ln_popdens := NA_real_]
scad_dt[!is.na(urban), ln_popdens := log(pop_dens + 1)]
# This will effectively drop all nationwide or regionally defined events.

##############################################
## SPATIALLY MERGING GEO EPR:
##############################################

setwd(data_dir)
# Suppressing warning related to NULL geographies:
epr_shp <- suppressWarnings(readOGR(dsn = "Cederman_GeoEPR", layer = "geoepr3",
    verbose = FALSE))

scad_xy <- unique(scad_dt[, .(longitude, latitude)])
coordinates(scad_xy) <- ~ longitude + latitude
proj4string(scad_xy) <- proj4string(epr_shp)

epr_shp@data <- epr_shp@data[,
    c("groupname", "startyear", "endyear", "pop2005", "type")]

# Using only the most current geographies
epr_shp <- epr_shp[epr_shp@data$endyear == 2009, ]

scad_epr <- over(scad_xy, epr_shp, returnList = TRUE)

# Assigning ID to each DF in list:
for(i in 1:length(scad_epr)) {
    temp_dt <- scad_epr[[i]]
    if(nrow(temp_dt) == 0) {next}
    else {
        temp_dt$id <- as.integer(names(scad_epr)[i])
        scad_epr[[i]] <- temp_dt
    }
    rm(list = c("temp_dt", "i"))
}

scad_epr <- rbindlist(scad_epr, fill = TRUE)
scad_epr[, multiple_matches := as.integer(.N > 1), by = id]
scad_epr[, groupname := as.character(groupname)]
tot_num <- scad_epr[, id] %>% unique()

##############################################
# Dealing with overlapping polygons:

# (1) Single overlapping group:
keep_dt1 <- scad_epr[multiple_matches == 0, .(groupname, id)]
scad_epr <- scad_epr[multiple_matches == 1]

# (2) Largest non-aggregate group:
scad_epr[, lgst_nonagg := as.integer(pop2005 == max(pop2005[type != 5])),
    by = id]

keep_dt2 <- scad_epr[lgst_nonagg == 1, .(groupname, id)][, list(groupname = paste(groupname, collapse = "-")), by = id]

scad_epr <- scad_epr[id %nin% keep_dt2[, id]]

# (3) Collapsing overlapping aggregate groups:
keep_dt3 <- scad_epr[, list(groupname = paste(unique(groupname), collapse = "-")), by = id]

group_dt <- rbindlist(list(keep_dt1, keep_dt2, keep_dt3), use.names = TRUE)
# nrow(group_dt) == length(tot_num)
rm(tot_num)

rm(list = c("scad_epr", "epr_shp", "keep_dt1", "keep_dt2", "keep_dt3"))

##############################################
# Merging back to scad_dt:
scad_xy <- scad_xy %>% coordinates() %>% data.table()
scad_xy[, id := rownames(scad_xy) %>% as.integer()]

setkey(scad_xy, id)
setkey(group_dt, id)
scad_xy <- merge(scad_xy, group_dt, all.x = TRUE)

setkey(scad_xy, longitude, latitude)
setkey(scad_dt, longitude, latitude)
scad_dt <- merge(scad_dt, scad_xy[, .(longitude, latitude, groupname)])
rm(scad_xy)

##############################################
## AFRICAN LEADERS:
##############################################
scad_dt[, sdate := dmy(paste0(stday, "-", stmo, "-", styr))]
scad_dt[, edate := dmy(paste0(eday, "-", emo, "-", eyr))]

setwd(data_dir)
ldrs_dt <- read_csv("African_Leaders.csv") %>% data.table()
ldrs_dt[, leader_sdate := dmy(leader_sdate)]
ldrs_dt[, leader_edate := dmy(leader_edate)]

# Determining leader during protest:
# pb <- txtProgressBar(min = 0, max = nrow(scad_dt), style = 3)
for(i in 1:nrow(scad_dt)) {

    if(scad_dt[i, ccode] == 620 & scad_dt[i, sdate] > ymd("2011-08-23")) {
    # Exception for Libya post Aug 2011:
        scad_dt[i, leader := NA_character_]
    } else {
        temp_dt <- ldrs_dt[ccode == scad_dt[i, ccode]]
        diff <- temp_dt[, leader_edate] - scad_dt[i, edate]
        place <- which(diff == min(diff[diff > 0]))

        scad_dt[i, leader := temp_dt[place, leader]]
        rm(list = c("temp_dt", "diff", "place"))
    }
    # setTxtProgressBar(pb, i)
}

scad_dt[, leader_code := paste0(leader, "-", ccode)]
rm(ldrs_dt)

##############################################
print("Finished loading SCAD data.")

setwd(data_dir)
save(scad_dt, file = "SCAD/Prepared_SCAD.Rdata")
